@@ -6,7 +6,7 @@
 #' The \code{\link{pdf_text}} function renders all textboxes on a text canvas
 #' and returns a character vector of equal length to the number of pages in the
 #' PDF file. On the other hand, \code{\link{pdf_data}} is more low level and
-#' returns one data frame per page, containing one row for each texbox in the PDF.
+#' returns one data frame per page, containing one row for each textbox in the PDF.
 #'
 #' Note that \code{\link{pdf_data}} requires a recent version of libpoppler
 #' which might not be available on all Linux systems.
@@ -41,15 +41,19 @@ pdf_info <- function(pdf, opw = "", upw = "") {
 }
 
 #' @rdname pdftools
+#' @param raw return text in raw stream order. Default is to use physical layout order.
 #' @export
-pdf_text <- function(pdf, opw = "", upw = "") {
-  poppler_pdf_text(loadfile(pdf), opw, upw)
+pdf_text <- function(pdf, opw = "", upw = "", raw = FALSE) {
+  poppler_pdf_text(loadfile(pdf), opw, upw, raw)
 }
 
 #' @rdname pdftools
 #' @export
-pdf_data <- function(pdf, opw = "", upw = "") {
-  out <- poppler_pdf_data(loadfile(pdf), opw, upw)
+#' @param font_info if TRUE, extract font-data for each box. Be careful, this
+#' requires a very recent version of poppler and will error otherwise.
+pdf_data <- function(pdf, font_info = FALSE, opw = "", upw = "") {
+  font_info <- as.logical(font_info)
+  out <- poppler_pdf_data(loadfile(pdf), font_info, opw, upw)
   lapply(out, df_as_tibble)
 }
 
